from setuptools import setup

setup(
    name='estimagic',
    version='0.0.1',
    description='',
    long_description='',
    url='https://github.com/janosg',
    author='Janos Gabler',
    author_email='janos.gabler@gmail.com',
    packages=[],
    classifiers=['Development Status :: 1 - Planning'],
)
